@@ -606,6 +606,8 @@ function set_screen_options() {
 			case 'upload_per_page':
 			case 'edit_tags_per_page':
 			case 'plugins_per_page':
+			case 'export_personal_data_requests_per_page':
+			case 'remove_personal_data_requests_per_page':
 			// Network admin
 			case 'sites_network_per_page':
 			case 'users_network_per_page':
@@ -1018,13 +1020,31 @@ function wp_refresh_post_nonces( $response, $data, $screen_id ) {
 				'_ajax_linking_nonce' => wp_create_nonce( 'internal-linking' ),
 				'_wpnonce' => wp_create_nonce( 'update-post_' . $post_id ),
 			),
-			'heartbeatNonce' => wp_create_nonce( 'heartbeat-nonce' ),
 		);
 	}
 
 	return $response;
 }
 
+/**
+ * Add the latest Heartbeat and REST-API nonce to the Heartbeat response.
+ *
+ * @since 5.0.0
+ *
+ * @param array  $response  The Heartbeat response.
+ * @return array The Heartbeat response.
+ */
+function wp_refresh_heartbeat_nonces( $response ) {
+	// Refresh the Rest API nonce.
+	$response['rest_nonce'] = wp_create_nonce( 'wp_rest' );
+	// TEMPORARY: Compat with api-fetch library
+	$response['rest-nonce'] = $response['rest_nonce'];
+
+	// Refresh the Heartbeat nonce.
+	$response['heartbeat_nonce'] = wp_create_nonce( 'heartbeat-nonce' );
+	return $response;
+}
+
 /**
  * Disable suspension of Heartbeat on the Add/Edit Post screens.
  *
@@ -1222,6 +1242,27 @@ All at ###SITENAME###
 	}
 }
 
+/**
+ * Appends '(Draft)' to draft page titles in the privacy page dropdown
+ * so that unpublished content is obvious.
+ *
+ * @since 4.9.8
+ * @access private
+ *
+ * @param string  $title Page title.
+ * @param WP_Post $page  Page data object.
+ *
+ * @return string Page title.
+ */
+function _wp_privacy_settings_filter_draft_page_titles( $title, $page ) {
+	if ( 'draft' === $page->post_status && 'privacy' === get_current_screen()->id ) {
+		/* translators: %s: Page Title */
+		$title = sprintf( __( '%s (Draft)' ), $title );
+	}
+
+	return $title;
+}
+
 /**
  * WP_Privacy_Policy_Content class.
  * TODO: move this to a new file.
@@ -1248,7 +1289,7 @@ final class WP_Privacy_Policy_Content {
 	 *
 	 * Intended for use from `wp_add_privacy_policy_content()`.
 	 *
-	 * $since 4.9.6
+	 * @since 4.9.6
 	 *
 	 * @param string $plugin_name The name of the plugin or theme that is suggesting content for the site's privacy policy.
 	 * @param string $policy_text The suggested content for inclusion in the policy.
@@ -1517,10 +1558,13 @@ final class WP_Privacy_Policy_Content {
 	 * Add a notice with a link to the guide when editing the privacy policy page.
 	 *
 	 * @since 4.9.6
+	 * @since 5.0.0 The $post parameter is now optional.
 	 *
-	 * @param $post WP_Post The currently edited post.
+	 * @param WP_Post|null $post The currently edited post. Default null.
 	 */
-	public static function notice( $post ) {
+	public static function notice( $post = null ) {
+		$post = get_post( $post );
+
 		if ( ! ( $post instanceof WP_Post ) ) {
 			return;
 		}
@@ -1651,142 +1695,252 @@ final class WP_Privacy_Policy_Content {
 	 * Return the default suggested privacy policy content.
 	 *
 	 * @since 4.9.6
+	 * @since 5.0.0 Added the `$blocks` parameter.
 	 *
-	 * @param bool $descr Whether to include the descriptions under the section headings. Default false.
+	 * @param bool $description Whether to include the descriptions under the section headings. Default false.
+	 * @param bool $blocks      Whether to format the content for the block editor. Default true.
 	 * @return string The default policy content.
 	 */
-	public static function get_default_content( $descr = false ) {
-		$suggested_text = $descr ? '<strong class="privacy-policy-tutorial">' . __( 'Suggested text:' ) . ' </strong>' : '';
+	public static function get_default_content( $description = false, $blocks = true ) {
+		$suggested_text = $description ? '<strong class="privacy-policy-tutorial">' . __( 'Suggested text:' ) . ' </strong>' : '';
 		$content = '';
+		$strings = array();
 
 		// Start of the suggested privacy policy text.
-		$descr && $content .=
-			'<div class="wp-suggested-text">';
-		$content .=
-			'<h2>' . __( 'Who we are' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should note your site URL, as well as the name of the company, organization, or individual behind it, and some accurate contact information.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'The amount of information you may be required to show will vary depending on your local or national business regulations. You may, for example, be required to display a physical address, a registered address, or your company registration number.' ) . '</p>';
-		$content .=
-			/* translators: %s Site URL */
-			'<p>' . $suggested_text . sprintf( __( 'Our website address is: %s.' ), get_bloginfo( 'url', 'display' ) ) . '</p>' .
+		if ( $description ) {
+			$strings[] = '<div class="wp-suggested-text">';
+		}
 
-			'<h2>' . __( 'What personal data we collect and why we collect it' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should note what personal data you collect from users and site visitors. This may include personal data, such as name, email address, personal account preferences; transactional data, such as purchase information; and technical data, such as information about cookies.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'You should also note any collection and retention of sensitive personal data, such as data concerning health.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'In addition to listing what personal data you collect, you need to note why you collect it. These explanations must note either the legal basis for your data collection and retention or the active consent the user has given.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'Personal data is not just created by a user&#8217;s interactions with your site. Personal data is also generated from technical processes such as contact forms, comments, cookies, analytics, and third party embeds.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not collect any personal data about visitors, and only collects the data shown on the User Profile screen from registered users. However some of your plugins may collect personal data. You should add the relevant information below.' ) . '</p>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'Who we are' ) . '</h2>';
 
-		$content .=
-			'<h3>' . __( 'Comments' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what information is captured through comments. We have noted the data which WordPress collects by default.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'When visitors leave comments on the site we collect the data shown in the comments form, and also the visitor&#8217;s IP address and browser user agent string to help spam detection.' ) . '</p>' .
-			'<p>' . __( 'An anonymized string created from your email address (also called a hash) may be provided to the Gravatar service to see if you are using it. The Gravatar service privacy policy is available here: https://automattic.com/privacy/. After approval of your comment, your profile picture is visible to the public in the context of your comment.' ) . '</p>' .
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should note your site URL, as well as the name of the company, organization, or individual behind it, and some accurate contact information.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'The amount of information you may be required to show will vary depending on your local or national business regulations. You may, for example, be required to display a physical address, a registered address, or your company registration number.' ) . '</p>';
+		}
 
-			'<h3>' . __( 'Media' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what information may be disclosed by users who can upload media files. All uploaded files are usually publicly accessible.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'If you upload images to the website, you should avoid uploading images with embedded location data (EXIF GPS) included. Visitors to the website can download and extract any location data from images on the website.' ) . '</p>' .
+		/* translators: default privacy policy text, %s Site URL. */
+		$strings[] = '<p>' . $suggested_text . sprintf( __( 'Our website address is: %s.' ), get_bloginfo( 'url', 'display' ) ) . '</p>';
 
-			'<h3>' . __( 'Contact forms' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'By default, WordPress does not include a contact form. If you use a contact form plugin, use this subsection to note what personal data is captured when someone submits a contact form, and how long you keep it. For example, you may note that you keep contact form submissions for a certain period for customer service purposes, but you do not use the information submitted through them for marketing purposes.' ) . '</p>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'What personal data we collect and why we collect it' ) . '</h2>';
 
-		$content .=
-			'<h3>' . __( 'Cookies' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this subsection you should list the cookies your web site uses, including those set by your plugins, social media, and analytics. We have provided the cookies which WordPress installs by default.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'If you leave a comment on our site you may opt-in to saving your name, email address and website in cookies. These are for your convenience so that you do not have to fill in your details again when you leave another comment. These cookies will last for one year.' ) . '</p>' .
-			'<p>' . __( 'If you have an account and you log in to this site, we will set a temporary cookie to determine if your browser accepts cookies. This cookie contains no personal data and is discarded when you close your browser.' ) . '</p>' .
-			'<p>' . __( 'When you log in, we will also set up several cookies to save your login information and your screen display choices. Login cookies last for two days, and screen options cookies last for a year. If you select &quot;Remember Me&quot;, your login will persist for two weeks. If you log out of your account, the login cookies will be removed.' ) . '</p>' .
-			'<p>' . __( 'If you edit or publish an article, an additional cookie will be saved in your browser. This cookie includes no personal data and simply indicates the post ID of the article you just edited. It expires after 1 day.' ) . '</p>' .
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should note what personal data you collect from users and site visitors. This may include personal data, such as name, email address, personal account preferences; transactional data, such as purchase information; and technical data, such as information about cookies.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'You should also note any collection and retention of sensitive personal data, such as data concerning health.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In addition to listing what personal data you collect, you need to note why you collect it. These explanations must note either the legal basis for your data collection and retention or the active consent the user has given.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'Personal data is not just created by a user&#8217;s interactions with your site. Personal data is also generated from technical processes such as contact forms, comments, cookies, analytics, and third party embeds.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not collect any personal data about visitors, and only collects the data shown on the User Profile screen from registered users. However some of your plugins may collect personal data. You should add the relevant information below.' ) . '</p>';
+		}
 
-			'<h3>' . __( 'Embedded content from other websites' ) . '</h3>' .
-			'<p>' . $suggested_text . __( 'Articles on this site may include embedded content (e.g. videos, images, articles, etc.). Embedded content from other websites behaves in the exact same way as if the visitor has visited the other website.' ) . '</p>' .
-			'<p>' . __( 'These websites may collect data about you, use cookies, embed additional third-party tracking, and monitor your interaction with that embedded content, including tracking your interaction with the embedded content if you have an account and are logged in to that website.' ) . '</p>' .
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Comments' ) . '</h3>';
 
-			'<h3>' . __( 'Analytics' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what analytics package you use, how users can opt out of analytics tracking, and a link to your analytics provider&#8217;s privacy policy, if any.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not collect any analytics data. However, many web hosting accounts collect some anonymous analytics data. You may also have installed a WordPress plugin that provides analytics services. In that case, add information from that plugin here.' ) . '</p>';
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what information is captured through comments. We have noted the data which WordPress collects by default.' ) . '</p>';
+		}
 
-		$content .=
-			'<h2>' . __( 'Who we share your data with' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should name and list all third party providers with whom you share site data, including partners, cloud-based services, payment processors, and third party service providers, and note what data you share with them and why. Link to their own privacy policies if possible.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not share any personal data with anyone.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'When visitors leave comments on the site we collect the data shown in the comments form, and also the visitor&#8217;s IP address and browser user agent string to help spam detection.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'An anonymized string created from your email address (also called a hash) may be provided to the Gravatar service to see if you are using it. The Gravatar service privacy policy is available here: https://automattic.com/privacy/. After approval of your comment, your profile picture is visible to the public in the context of your comment.' ) . '</p>';
 
-		$content .=
-			'<h2>' . __( 'How long we retain your data' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should explain how long you retain personal data collected or processed by the web site. While it is your responsibility to come up with the schedule of how long you keep each dataset for and why you keep it, that information does need to be listed here. For example, you may want to say that you keep contact form entries for six months, analytics records for a year, and customer purchase records for ten years.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'If you leave a comment, the comment and its metadata are retained indefinitely. This is so we can recognize and approve any follow-up comments automatically instead of holding them in a moderation queue.' ) . '</p>' .
-			'<p>' . __( 'For users that register on our website (if any), we also store the personal information they provide in their user profile. All users can see, edit, or delete their personal information at any time (except they cannot change their username). Website administrators can also see and edit that information.' ) . '</p>' .
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Media' ) . '</h3>';
 
-			'<h2>' . __( 'What rights you have over your data' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what rights your users have over their data and how they can invoke those rights.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'If you have an account on this site, or have left comments, you can request to receive an exported file of the personal data we hold about you, including any data you have provided to us. You can also request that we erase any personal data we hold about you. This does not include any data we are obliged to keep for administrative, legal, or security purposes.' ) . '</p>' .
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what information may be disclosed by users who can upload media files. All uploaded files are usually publicly accessible.' ) . '</p>';
+		}
 
-			'<h2>' . __( 'Where we send your data' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should list all transfers of your site data outside the European Union and describe the means by which that data is safeguarded to European data protection standards. This could include your web hosting, cloud storage, or other third party services.' ) . '</p>' .
-			'<p class="privacy-policy-tutorial">' . __( 'European data protection law requires data about European residents which is transferred outside the European Union to be safeguarded to the same standards as if the data was in Europe. So in addition to listing where data goes, you should describe how you ensure that these standards are met either by yourself or by your third party providers, whether that is through an agreement such as Privacy Shield, model clauses in your contracts, or binding corporate rules.' ) . '</p>';
-		$content .=
-			'<p>' . $suggested_text . __( 'Visitor comments may be checked through an automated spam detection service.' ) . '</p>' .
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'If you upload images to the website, you should avoid uploading images with embedded location data (EXIF GPS) included. Visitors to the website can download and extract any location data from images on the website.' ) . '</p>';
 
-			'<h2>' . __( 'Your contact information' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should provide a contact method for privacy-specific concerns. If you are required to have a Data Protection Officer, list their name and full contact details here as well.' ) . '</p>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Contact forms' ) . '</h3>';
 
-		$content .=
-			'<h2>' . __( 'Additional information' ) . '</h2>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'If you use your site for commercial purposes and you engage in more complex collection or processing of personal data, you should note the following information in your privacy policy in addition to the information we have already discussed.' ) . '</p>';
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'By default, WordPress does not include a contact form. If you use a contact form plugin, use this subsection to note what personal data is captured when someone submits a contact form, and how long you keep it. For example, you may note that you keep contact form submissions for a certain period for customer service purposes, but you do not use the information submitted through them for marketing purposes.' ) . '</p>';
+		}
 
-		$content .=
-			'<h3>' . __( 'How we protect your data' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what measures you have taken to protect your users&#8217; data. This could include technical measures such as encryption; security measures such as two factor authentication; and measures such as staff training in data protection. If you have carried out a Privacy Impact Assessment, you can mention it here too.' ) . '</p>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Cookies' ) . '</h3>';
 
-		$content .=
-			'<h3>' . __( 'What data breach procedures we have in place' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what procedures you have in place to deal with data breaches, either potential or real, such as internal reporting systems, contact mechanisms, or bug bounties.' ) . '</p>';
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this subsection you should list the cookies your web site uses, including those set by your plugins, social media, and analytics. We have provided the cookies which WordPress installs by default.' ) . '</p>';
+		}
 
-		$content .=
-			'<h3>' . __( 'What third parties we receive data from' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'If your web site receives data about users from third parties, including advertisers, this information must be included within the section of your privacy policy dealing with third party data.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'If you leave a comment on our site you may opt-in to saving your name, email address and website in cookies. These are for your convenience so that you do not have to fill in your details again when you leave another comment. These cookies will last for one year.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'If you have an account and you log in to this site, we will set a temporary cookie to determine if your browser accepts cookies. This cookie contains no personal data and is discarded when you close your browser.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'When you log in, we will also set up several cookies to save your login information and your screen display choices. Login cookies last for two days, and screen options cookies last for a year. If you select &quot;Remember Me&quot;, your login will persist for two weeks. If you log out of your account, the login cookies will be removed.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'If you edit or publish an article, an additional cookie will be saved in your browser. This cookie includes no personal data and simply indicates the post ID of the article you just edited. It expires after 1 day.' ) . '</p>';
 
-		$content .=
-			'<h3>' . __( 'What automated decision making and/or profiling we do with user data' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'If your web site provides a service which includes automated decision making - for example, allowing customers to apply for credit, or aggregating their data into an advertising profile - you must note that this is taking place, and include information about how that information is used, what decisions are made with that aggregated data, and what rights users have over decisions made without human intervention.' ) . '</p>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Embedded content from other websites' ) . '</h3>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'Articles on this site may include embedded content (e.g. videos, images, articles, etc.). Embedded content from other websites behaves in the exact same way as if the visitor has visited the other website.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'These websites may collect data about you, use cookies, embed additional third-party tracking, and monitor your interaction with that embedded content, including tracking your interaction with the embedded content if you have an account and are logged in to that website.' ) . '</p>';
 
-		$content .=
-			'<h3>' . __( 'Industry regulatory disclosure requirements' ) . '</h3>';
-		$descr && $content .=
-			'<p class="privacy-policy-tutorial">' . __( 'If you are a member of a regulated industry, or if you are subject to additional privacy laws, you may be required to disclose that information here.' ) . '</p>' .
-			'</div>';
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Analytics' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this subsection you should note what analytics package you use, how users can opt out of analytics tracking, and a link to your analytics provider&#8217;s privacy policy, if any.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not collect any analytics data. However, many web hosting accounts collect some anonymous analytics data. You may also have installed a WordPress plugin that provides analytics services. In that case, add information from that plugin here.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'Who we share your data with' ) . '</h2>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should name and list all third party providers with whom you share site data, including partners, cloud-based services, payment processors, and third party service providers, and note what data you share with them and why. Link to their own privacy policies if possible.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'By default WordPress does not share any personal data with anyone.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'How long we retain your data' ) . '</h2>';
+		
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should explain how long you retain personal data collected or processed by the web site. While it is your responsibility to come up with the schedule of how long you keep each dataset for and why you keep it, that information does need to be listed here. For example, you may want to say that you keep contact form entries for six months, analytics records for a year, and customer purchase records for ten years.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'If you leave a comment, the comment and its metadata are retained indefinitely. This is so we can recognize and approve any follow-up comments automatically instead of holding them in a moderation queue.' ) . '</p>';
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . __( 'For users that register on our website (if any), we also store the personal information they provide in their user profile. All users can see, edit, or delete their personal information at any time (except they cannot change their username). Website administrators can also see and edit that information.' ) . '</p>';
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'What rights you have over your data' ) . '</h2>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what rights your users have over their data and how they can invoke those rights.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'If you have an account on this site, or have left comments, you can request to receive an exported file of the personal data we hold about you, including any data you have provided to us. You can also request that we erase any personal data we hold about you. This does not include any data we are obliged to keep for administrative, legal, or security purposes.' ) . '</p>';
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'Where we send your data' ) . '</h2>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should list all transfers of your site data outside the European Union and describe the means by which that data is safeguarded to European data protection standards. This could include your web hosting, cloud storage, or other third party services.' ) . '</p>';
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'European data protection law requires data about European residents which is transferred outside the European Union to be safeguarded to the same standards as if the data was in Europe. So in addition to listing where data goes, you should describe how you ensure that these standards are met either by yourself or by your third party providers, whether that is through an agreement such as Privacy Shield, model clauses in your contracts, or binding corporate rules.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy text. */
+		$strings[] = '<p>' . $suggested_text . __( 'Visitor comments may be checked through an automated spam detection service.' ) . '</p>';
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'Your contact information' ) . '</h2>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should provide a contact method for privacy-specific concerns. If you are required to have a Data Protection Officer, list their name and full contact details here as well.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h2>' . __( 'Additional information' ) . '</h2>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'If you use your site for commercial purposes and you engage in more complex collection or processing of personal data, you should note the following information in your privacy policy in addition to the information we have already discussed.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'How we protect your data' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what measures you have taken to protect your users&#8217; data. This could include technical measures such as encryption; security measures such as two factor authentication; and measures such as staff training in data protection. If you have carried out a Privacy Impact Assessment, you can mention it here too.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'What data breach procedures we have in place' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'In this section you should explain what procedures you have in place to deal with data breaches, either potential or real, such as internal reporting systems, contact mechanisms, or bug bounties.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'What third parties we receive data from' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'If your web site receives data about users from third parties, including advertisers, this information must be included within the section of your privacy policy dealing with third party data.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'What automated decision making and/or profiling we do with user data' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'If your web site provides a service which includes automated decision making - for example, allowing customers to apply for credit, or aggregating their data into an advertising profile - you must note that this is taking place, and include information about how that information is used, what decisions are made with that aggregated data, and what rights users have over decisions made without human intervention.' ) . '</p>';
+		}
+
+		/* translators: default privacy policy heading. */
+		$strings[] = '<h3>' . __( 'Industry regulatory disclosure requirements' ) . '</h3>';
+
+		if ( $description ) {
+			/* translators: privacy policy tutorial. */
+			$strings[] = '<p class="privacy-policy-tutorial">' . __( 'If you are a member of a regulated industry, or if you are subject to additional privacy laws, you may be required to disclose that information here.' ) . '</p>';
+			$strings[] = '</div>';
+		}
+
+		if ( $blocks ) {
+			foreach ( $strings as $key => $string ) {
+				if ( 0 === strpos( $string, '<p>' ) ) {
+					$strings[ $key ] = '<!-- wp:paragraph -->' . $string . '<!-- /wp:paragraph -->';
+				}
+
+				if ( 0 === strpos( $string, '<h2>' ) ) {
+					$strings[ $key ] = '<!-- wp:heading -->' . $string . '<!-- /wp:heading -->';
+				}
+
+				if ( 0 === strpos( $string, '<h3>' ) ) {
+					$strings[ $key ] = '<!-- wp:heading {"level":3} -->' . $string . '<!-- /wp:heading -->';
+				}
+			}
+		}
+
+		$content = implode( '', $strings );
 		// End of the suggested privacy policy text.
 
 		/**
 		 * Filters the default content suggested for inclusion in a privacy policy.
 		 *
 		 * @since 4.9.6
+		 * @since 5.0.0 Added the `$strings`, `$description`, and `$blocks` parameters.
 		 *
-		 * @param $content string The default policy content.
+		 * @param $content     string The default policy content.
+		 * @param $strings     array  An array of privacy policy content strings.
+		 * @param $description bool   Whether policy descriptions should be included.
+		 * @param $blocks      bool   Whether the content should be formatted for the block editor.
 		 */
-		return apply_filters( 'wp_get_default_privacy_policy_content', $content );
+		return apply_filters( 'wp_get_default_privacy_policy_content', $content, $strings, $description, $blocks );
 	}
 
 	/**
@@ -1795,7 +1949,7 @@ final class WP_Privacy_Policy_Content {
 	 * @since 4.9.6
 	 */
 	public static function add_suggested_content() {
-		$content = self::get_default_content( true );
+		$content = self::get_default_content( true, false );
 		wp_add_privacy_policy_content( __( 'WordPress' ), $content );
 	}
 }
