@@ -12,7 +12,6 @@ class WP {
 	 * Long list of public query variables.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var array
 	 */
 	public $public_query_vars = array('m', 'p', 'posts', 'w', 'cat', 'withcomments', 'withoutcomments', 's', 'search', 'exact', 'sentence', 'calendar', 'page', 'paged', 'more', 'tb', 'pb', 'author', 'order', 'orderby', 'year', 'monthnum', 'day', 'hour', 'minute', 'second', 'name', 'category_name', 'tag', 'feed', 'author_name', 'static', 'pagename', 'page_id', 'error', 'attachment', 'attachment_id', 'subpost', 'subpost_id', 'preview', 'robots', 'taxonomy', 'term', 'cpage', 'post_type', 'embed' );
@@ -23,7 +22,6 @@ class WP {
 	 * Long list of private query variables.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var array
 	 */
 	public $private_query_vars = array( 'offset', 'posts_per_page', 'posts_per_archive_page', 'showposts', 'nopaging', 'post_type', 'post_status', 'category__in', 'category__not_in', 'category__and', 'tag__in', 'tag__not_in', 'tag__and', 'tag_slug__in', 'tag_slug__and', 'tag_id', 'post_mime_type', 'perm', 'comments_per_page', 'post__in', 'post__not_in', 'post_parent', 'post_parent__in', 'post_parent__not_in', 'title', 'fields' );
@@ -32,7 +30,6 @@ class WP {
 	 * Extra query variables set by the user.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 * @var array
 	 */
 	public $extra_query_vars = array();
@@ -41,7 +38,6 @@ class WP {
 	 * Query variables for setting up the WordPress Query Loop.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var array
 	 */
 	public $query_vars;
@@ -50,7 +46,6 @@ class WP {
 	 * String parsed to set the query variables.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var string
 	 */
 	public $query_string;
@@ -59,7 +54,6 @@ class WP {
 	 * The request path, e.g. 2015/05/06.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var string
 	 */
 	public $request;
@@ -68,7 +62,6 @@ class WP {
 	 * Rewrite rule the request matched.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var string
 	 */
 	public $matched_rule;
@@ -77,7 +70,6 @@ class WP {
 	 * Rewrite query the request matched.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var string
 	 */
 	public $matched_query;
@@ -86,7 +78,6 @@ class WP {
 	 * Whether already did the permalink.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var bool
 	 */
 	public $did_permalink = false;
@@ -95,7 +86,6 @@ class WP {
 	 * Add name to list of public query variables.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 *
 	 * @param string $qv Query variable name.
 	 */
@@ -108,7 +98,6 @@ class WP {
 	 * Removes a query variable from a list of public query variables.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 *
 	 * @param string $name Query variable name.
 	 */
@@ -120,7 +109,6 @@ class WP {
 	 * Set the value of a query variable.
 	 *
 	 * @since 2.3.0
-	 * @access public
 	 *
 	 * @param string $key Query variable name.
 	 * @param mixed $value Query variable value.
@@ -136,7 +124,6 @@ class WP {
 	 * filters and actions that can be used to further manipulate the result.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @global WP_Rewrite $wp_rewrite
 	 *
@@ -302,6 +289,8 @@ class WP {
 		foreach ( $this->public_query_vars as $wpvar ) {
 			if ( isset( $this->extra_query_vars[$wpvar] ) )
 				$this->query_vars[$wpvar] = $this->extra_query_vars[$wpvar];
+			elseif ( isset( $_GET[ $wpvar ] ) && isset( $_POST[ $wpvar ] ) && $_GET[ $wpvar ] !== $_POST[ $wpvar ] )
+				wp_die( __( 'A variable mismatch has been detected.' ), __( 'Sorry, you are not allowed to view this item.' ), 400 );
 			elseif ( isset( $_POST[$wpvar] ) )
 				$this->query_vars[$wpvar] = $_POST[$wpvar];
 			elseif ( isset( $_GET[$wpvar] ) )
@@ -381,7 +370,7 @@ class WP {
 		 *
 		 * @since 2.1.0
 		 *
-		 * @param WP &$this Current WordPress environment instance (passed by reference).
+		 * @param WP $this Current WordPress environment instance (passed by reference).
 		 */
 		do_action_ref_array( 'parse_request', array( &$this ) );
 	}
@@ -394,7 +383,6 @@ class WP {
 	 *
 	 * @since 2.0.0
 	 * @since 4.4.0 `X-Pingback` header is added conditionally after posts have been queried in handle_404().
-	 * @access public
 	 */
 	public function send_headers() {
 		$headers = array();
@@ -513,7 +501,7 @@ class WP {
 		 *
 		 * @since 2.1.0
 		 *
-		 * @param WP &$this Current WordPress environment instance (passed by reference).
+		 * @param WP $this Current WordPress environment instance (passed by reference).
 		 */
 		do_action_ref_array( 'send_headers', array( &$this ) );
 	}
@@ -525,7 +513,6 @@ class WP {
 	 * use the {@see 'request'} filter instead.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 */
 	public function build_query_string() {
 		$this->query_string = '';
@@ -560,7 +547,6 @@ class WP {
 	 * WordPress environment.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @global WP_Query     $wp_query
 	 * @global string       $query_string Query string for the loop.
@@ -597,7 +583,6 @@ class WP {
 	 * Set up the current user.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 */
 	public function init() {
 		wp_get_current_user();
@@ -607,7 +592,6 @@ class WP {
 	 * Set up the Loop based on the query variables.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @global WP_Query $wp_the_query
 	 */
@@ -631,8 +615,7 @@ class WP {
 	 * a 404 so that canonical redirection logic can kick in.
 	 *
 	 * @since 2.0.0
-     * @access public
-	 *
+     *
 	 * @global WP_Query $wp_query
  	 */
 	public function handle_404() {
@@ -724,7 +707,6 @@ class WP {
 	 * object.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string|array $query_args Passed to parse_request().
 	 */
@@ -741,7 +723,7 @@ class WP {
 		 *
 		 * @since 2.1.0
 		 *
-		 * @param WP &$this Current WordPress environment instance (passed by reference).
+		 * @param WP $this Current WordPress environment instance (passed by reference).
 		 */
 		do_action_ref_array( 'wp', array( &$this ) );
 	}
