@@ -34,7 +34,6 @@ function get_query_var( $var, $default = '' ) {
  * Wrapper for WP_Query::get_queried_object().
  *
  * @since 3.1.0
- * @access public
  *
  * @global WP_Query $wp_query Global WP_Query instance.
  *
@@ -137,10 +136,14 @@ function wp_reset_postdata() {
  */
 
 /**
- * Is the query for an existing archive page?
+ * Determines whether the query is for an existing archive page.
  *
  * Month, Year, Category, Author, Post Type archive...
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -159,8 +162,12 @@ function is_archive() {
 }
 
 /**
- * Is the query for an existing post type archive page?
- *
+ * Determines whether the query is for an existing post type archive page.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 3.1.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -180,8 +187,12 @@ function is_post_type_archive( $post_types = '' ) {
 }
 
 /**
- * Is the query for an existing attachment page?
- *
+ * Determines whether the query is for an existing attachment page.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 2.0.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -201,11 +212,15 @@ function is_attachment( $attachment = '' ) {
 }
 
 /**
- * Is the query for an existing author archive page?
+ * Determines whether the query is for an existing author archive page.
  *
  * If the $author parameter is specified, this function will additionally
  * check if the query is for one of the authors specified.
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -225,11 +240,15 @@ function is_author( $author = '' ) {
 }
 
 /**
- * Is the query for an existing category archive page?
+ * Determines whether the query is for an existing category archive page.
  *
  * If the $category parameter is specified, this function will additionally
  * check if the query is for one of the categories specified.
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -249,10 +268,14 @@ function is_category( $category = '' ) {
 }
 
 /**
- * Is the query for an existing tag archive page?
+ * Determines whether the query is for an existing tag archive page.
  *
  * If the $tag parameter is specified, this function will additionally
  * check if the query is for one of the tags specified.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 2.3.0
  *
@@ -273,7 +296,7 @@ function is_tag( $tag = '' ) {
 }
 
 /**
- * Is the query for an existing custom taxonomy archive page?
+ * Determines whether the query is for an existing custom taxonomy archive page.
  *
  * If the $taxonomy parameter is specified, this function will additionally
  * check if the query is for that specific $taxonomy.
@@ -281,6 +304,10 @@ function is_tag( $tag = '' ) {
  * If the $term parameter is specified in addition to the $taxonomy parameter,
  * this function will additionally check if the query is for one of the terms
  * specified.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 2.5.0
  *
@@ -302,8 +329,12 @@ function is_tax( $taxonomy = '', $term = '' ) {
 }
 
 /**
- * Is the query for an existing date archive?
- *
+ * Determines whether the query is for an existing date archive.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -322,7 +353,11 @@ function is_date() {
 }
 
 /**
- * Is the query for an existing day archive?
+ * Determines whether the query is for an existing day archive.
+ *
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 1.5.0
  *
@@ -342,8 +377,12 @@ function is_day() {
 }
 
 /**
- * Is the query for a feed?
- *
+ * Determines whether the query is for a feed.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -383,7 +422,7 @@ function is_comment_feed() {
 }
 
 /**
- * Is the query for the front page of the site?
+ * Determines whether the query is for the front page of the site.
  *
  * This is for what is displayed at your site's main URL.
  *
@@ -393,7 +432,11 @@ function is_comment_feed() {
  * true when viewing that page.
  *
  * Otherwise the same as @see is_home()
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 2.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -412,7 +455,7 @@ function is_front_page() {
 }
 
 /**
- * Determines if the query is for the blog homepage.
+ * Determines whether the query is for the blog homepage.
  *
  * The blog homepage is the page that shows the time-based blog content of the site.
  *
@@ -421,7 +464,11 @@ function is_front_page() {
  *
  * If a static page is set for the front page of the site, this function will return true only
  * on the page you set as the "Posts page".
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @see is_front_page()
@@ -441,8 +488,12 @@ function is_home() {
 }
 
 /**
- * Is the query for an existing month archive?
- *
+ * Determines whether the query is for an existing month archive.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -461,11 +512,15 @@ function is_month() {
 }
 
 /**
- * Is the query for an existing single page?
+ * Determines whether the query is for an existing single page.
  *
  * If the $page parameter is specified, this function will additionally
  * check if the query is for one of the pages specified.
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @see is_single()
  * @see is_singular()
  *
@@ -488,8 +543,12 @@ function is_page( $page = '' ) {
 }
 
 /**
- * Is the query for paged result and not for the first page?
- *
+ * Determines whether the query is for paged results and not for the first page.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -508,8 +567,12 @@ function is_paged() {
 }
 
 /**
- * Is the query for a post or page preview?
- *
+ * Determines whether the query is for a post or page preview.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 2.0.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -548,8 +611,12 @@ function is_robots() {
 }
 
 /**
- * Is the query for a search?
- *
+ * Determines whether the query is for a search.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -568,13 +635,17 @@ function is_search() {
 }
 
 /**
- * Is the query for an existing single post?
+ * Determines whether the query is for an existing single post.
  *
  * Works for any post type, except attachments and pages
  *
  * If the $post parameter is specified, this function will additionally
  * check if the query is for one of the Posts specified.
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @see is_page()
  * @see is_singular()
  *
@@ -597,11 +668,16 @@ function is_single( $post = '' ) {
 }
 
 /**
- * Is the query for an existing single post of any post type (post, attachment, page, ... )?
+ * Determines whether the query is for an existing single post of any post type
+ * (post, attachment, page, custom post types).
  *
  * If the $post_types parameter is specified, this function will additionally
  * check if the query is for one of the Posts Types specified.
- *
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @see is_page()
  * @see is_single()
  *
@@ -624,7 +700,11 @@ function is_singular( $post_types = '' ) {
 }
 
 /**
- * Is the query for a specific time?
+ * Determines whether the query is for a specific time.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 1.5.0
  *
@@ -644,7 +724,11 @@ function is_time() {
 }
 
 /**
- * Is the query for a trackback endpoint call?
+ * Determines whether the query is for a trackback endpoint call.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 1.5.0
  *
@@ -664,7 +748,11 @@ function is_trackback() {
 }
 
 /**
- * Is the query for an existing year archive?
+ * Determines whether the query is for an existing year archive.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 1.5.0
  *
@@ -684,8 +772,12 @@ function is_year() {
 }
 
 /**
- * Is the query a 404 (returns no results)?
- *
+ * Determines whether the query has resulted in a 404 (returns no results).
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 1.5.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -724,8 +816,12 @@ function is_embed() {
 }
 
 /**
- * Is the query the main query?
- *
+ * Determines whether the query is the main query.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
+ * 
  * @since 3.3.0
  *
  * @global WP_Query $wp_query Global WP_Query instance.
@@ -768,7 +864,11 @@ function have_posts() {
 }
 
 /**
- * Whether the caller is in the Loop.
+ * Determines whether the caller is in the Loop.
+ * 
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/ 
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 2.0.0
  *
@@ -843,13 +943,9 @@ function the_comment() {
  * Attempts to find the current slug from the past slugs.
  *
  * @since 2.1.0
- *
- * @global wpdb $wpdb WordPress database abstraction object.
  */
 function wp_old_slug_redirect() {
 	if ( is_404() && '' !== get_query_var( 'name' ) ) {
-		global $wpdb;
-
 		// Guess the current post_type based on the query vars.
 		if ( get_query_var( 'post_type' ) ) {
 			$post_type = get_query_var( 'post_type' );
@@ -873,21 +969,20 @@ function wp_old_slug_redirect() {
 			return;
 		}
 
-		$query = $wpdb->prepare("SELECT post_id FROM $wpdb->postmeta, $wpdb->posts WHERE ID = post_id AND post_type = %s AND meta_key = '_wp_old_slug' AND meta_value = %s", $post_type, get_query_var( 'name' ) );
+		$id = _find_post_by_old_slug( $post_type );
 
-		// if year, monthnum, or day have been specified, make our query more precise
-		// just in case there are multiple identical _wp_old_slug values
-		if ( get_query_var( 'year' ) ) {
-			$query .= $wpdb->prepare(" AND YEAR(post_date) = %d", get_query_var( 'year' ) );
-		}
-		if ( get_query_var( 'monthnum' ) ) {
-			$query .= $wpdb->prepare(" AND MONTH(post_date) = %d", get_query_var( 'monthnum' ) );
-		}
-		if ( get_query_var( 'day' ) ) {
-			$query .= $wpdb->prepare(" AND DAYOFMONTH(post_date) = %d", get_query_var( 'day' ) );
+		if ( ! $id ) {
+			$id = _find_post_by_old_date( $post_type );
 		}
 
-		$id = (int) $wpdb->get_var( $query );
+		/**
+		 * Filters the old slug redirect post ID.
+		 *
+		 * @since 4.9.3
+		 *
+		 * @param int $id The redirect post ID.
+		 */
+		$id = apply_filters( 'old_slug_redirect_post_id', $id );
 
 		if ( ! $id ) {
 			return;
@@ -919,6 +1014,81 @@ function wp_old_slug_redirect() {
 	}
 }
 
+/**
+ * Find the post ID for redirecting an old slug.
+ *
+ * @see wp_old_slug_redirect()
+ *
+ * @since 4.9.3
+ * @access private
+ *
+ * @global wpdb $wpdb WordPress database abstraction object.
+ *
+ * @param string $post_type The current post type based on the query vars.
+ * @return int $id The Post ID.
+ */
+function _find_post_by_old_slug( $post_type ) {
+	global $wpdb;
+
+	$query = $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta, $wpdb->posts WHERE ID = post_id AND post_type = %s AND meta_key = '_wp_old_slug' AND meta_value = %s", $post_type, get_query_var( 'name' ) );
+
+	// if year, monthnum, or day have been specified, make our query more precise
+	// just in case there are multiple identical _wp_old_slug values
+	if ( get_query_var( 'year' ) ) {
+		$query .= $wpdb->prepare( " AND YEAR(post_date) = %d", get_query_var( 'year' ) );
+	}
+	if ( get_query_var( 'monthnum' ) ) {
+		$query .= $wpdb->prepare( " AND MONTH(post_date) = %d", get_query_var( 'monthnum' ) );
+	}
+	if ( get_query_var( 'day' ) ) {
+		$query .= $wpdb->prepare( " AND DAYOFMONTH(post_date) = %d", get_query_var( 'day' ) );
+	}
+
+	$id = (int) $wpdb->get_var( $query );
+
+	return $id;
+}
+
+/**
+ * Find the post ID for redirecting an old date.
+ *
+ * @see wp_old_slug_redirect()
+ *
+ * @since 4.9.3
+ * @access private
+ *
+ * @global wpdb $wpdb WordPress database abstraction object.
+ *
+ * @param string $post_type The current post type based on the query vars.
+ * @return int $id The Post ID.
+ */
+function _find_post_by_old_date( $post_type ) {
+	global $wpdb;
+
+	$date_query = '';
+	if ( get_query_var( 'year' ) ) {
+		$date_query .= $wpdb->prepare( " AND YEAR(pm_date.meta_value) = %d", get_query_var( 'year' ) );
+	}
+	if ( get_query_var( 'monthnum' ) ) {
+		$date_query .= $wpdb->prepare( " AND MONTH(pm_date.meta_value) = %d", get_query_var( 'monthnum' ) );
+	}
+	if ( get_query_var( 'day' ) ) {
+		$date_query .= $wpdb->prepare( " AND DAYOFMONTH(pm_date.meta_value) = %d", get_query_var( 'day' ) );
+	}
+
+	$id = 0;
+	if ( $date_query ) {
+		$id = (int) $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta AS pm_date, $wpdb->posts WHERE ID = post_id AND post_type = %s AND meta_key = '_wp_old_date' AND post_name = %s" . $date_query, $post_type, get_query_var( 'name' ) ) );
+
+		if ( ! $id ) {
+			// Check to see if an old slug matches the old date
+			$id = (int) $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts, $wpdb->postmeta AS pm_slug, $wpdb->postmeta AS pm_date WHERE ID = pm_slug.post_id AND ID = pm_date.post_id AND post_type = %s AND pm_slug.meta_key = '_wp_old_slug' AND pm_slug.meta_value = %s AND pm_date.meta_key = '_wp_old_date'" . $date_query, $post_type, get_query_var( 'name' ) ) );
+		}
+	}
+
+	return $id;
+}
+
 /**
  * Set up global post data.
  *
